@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: libcyr_cfg.h,v 1.12 2008/07/30 16:03:39 murch Exp $
+ * $Id: libcyr_cfg.h,v 1.14 2010/01/06 17:01:46 murch Exp $
  */
 
 #ifndef INCLUDED_LIBCYR_CFG_H
@@ -86,6 +86,8 @@ enum cyrus_opt {
     CYRUSOPT_FULLDIRHASH,
     /* Database for use by AUTH_PTS */
     CYRUSOPT_PTSCACHE_DB,
+    /* Path to database for use by AUTH_PTS */
+    CYRUSOPT_PTSCACHE_DB_PATH,
     /* ptloader socket for use by AUTH_PTS */
     CYRUSOPT_PTLOADER_SOCK,
     /* Virtual Domains (OFF) */
@@ -112,6 +114,8 @@ enum cyrus_opt {
     CYRUSOPT_SQL_PASSWD,
     /* Secure SQL connection (OFF) */
     CYRUSOPT_SQL_USESSL,
+    /* Checkpoint after every recovery (OFF) */
+    CYRUSOPT_SKIPLIST_ALWAYS_CHECKPOINT,
 
     CYRUSOPT_LAST
     
